@@ -76,14 +76,15 @@ def _try_pull_from_pip(package):
 
 def get_requirement_version(package_name, dependency_name):
     """Get assigned version to a dependency in package requirements."""
-    fixed_name = package_name.replace('pollination.', 'pollination_')
+    package_name = package_name.replace('pollination.', 'pollination_')
+    package_name = name_to_pollination(package_name)
     dependency_name = dependency_name.replace('_', '-')
     requirements = {}
     try:
-        req = pkg_resources.get_distribution(fixed_name).get_metadata('requires.txt')
+        req = pkg_resources.get_distribution(package_name).get_metadata('requires.txt')
     except FileNotFoundError:
         # try to get it from meta data
-        package_data = importlib_metadata.metadata(fixed_name)
+        package_data = importlib_metadata.metadata(package_name)
         req_dists = package_data.get_all('Requires-Dist') or []
         for package in req_dists:
             name, version = package.split(' (')
@@ -103,20 +104,24 @@ def get_requirement_version(package_name, dependency_name):
     return requirements[dependency_name]
 
 
-def get_docker_image_from_dependency(package, dependency, owner):
+def get_docker_image_from_dependency(package, dependency, owner, alias=None):
     """Get a docker image id from package information.
 
     Arguments:
         package: Name of the package (e.g. pollination-honeybee-radiance)
         dependency: Name of the dependency (e.g. honeybee-radiance)
         owner: The account owner for docker image
+        alias: An alias name for the docker image. This input is useful in cases that
+            docker image name (e.g. ladybug) is different from the dependency name
+            (e.g. ladybug-core).
 
     Returns:
         str -- docker image id (e.g. ladybugtools/honeybee-radiance:0.5.2)
     """
+    image_name = alias if alias else dependency
     try:
         image_version = get_requirement_version(package, dependency)
-        image_id = f'ladybugtools/{dependency}:{image_version}'
+        image_id = f'{owner}/{image_name}:{image_version}'
     except (FileNotFoundError, AssertionError) as error:
         # this should not happen if the package is installed correctly
         # but Python has so many ways to store requirements based on how the package
@@ -125,7 +130,7 @@ def get_docker_image_from_dependency(package, dependency, owner):
             f'Failed to pinpoint the version for {dependency} as a dependency for'
             f' {package}. Will set the docker version to latest.\n{error}'
         )
-        image_id = f'ladybugtools/{dependency}:latest'
+        image_id = f'{owner}/{image_name}:latest'
 
     return image_id
 
@@ -258,7 +263,8 @@ def _get_package_data(package_name: str) -> Dict:
 
 
 def _get_meta_data(module, package_type: str) -> MetaData:
-    qb_info = module.__pollination__
+    """Get package metadata."""
+    qb_info = dict(module.__pollination__)
     package_data = _get_package_data(module.__name__)
 
     if package_type == 'plugin':
@@ -295,10 +301,6 @@ class _BaseClass:
     def queenbee(self):
         raise NotImplementedError
 
-    @property
-    def _outputs(self) -> NamedTuple:
-        raise NotImplementedError
-
     @property
     def _inputs(self) -> NamedTuple:
         """Return inputs as a simple object with dot notation.
@@ -324,6 +326,29 @@ class _BaseClass:
 
         return self._cached_inputs
 
+    @property
+    def _outputs(self) -> NamedTuple:
+        """Return outputs as a simple object with dot notation.
+
+        Use this property to access the outputs when creating a DAG.
+
+        The name starts with a _ not to conflict with a possible member of the class
+        with the name outputs.
+        """
+        if self._cached_outputs:
+            return self._cached_outputs
+        cls_name = camel_to_snake(self.__class__.__name__)
+        mapper = {
+            out.name.replace('-', '_'): {
+                'name': out.name.replace('-', '_'),
+                'parent': cls_name, 'value': out
+            } for out in self.queenbee.outputs
+        }
+        outputs = namedtuple('Outputs', list(mapper.keys()))
+        self._cached_outputs = outputs(*list(mapper.values()))
+
+        return self._cached_outputs
+
     @property
     def _package(self) -> dict:
         """Queenbee package information.
